package com.xeuse.stuffmypetdestroyed;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;

import org.apache.http.HttpResponse;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.DefaultHttpClient;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.util.Log;
import android.view.LayoutInflater;
import android.widget.AbsListView;
import android.widget.AbsListView.OnScrollListener;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

import com.actionbarsherlock.view.Menu;
import com.actionbarsherlock.view.MenuInflater;
import com.actionbarsherlock.view.MenuItem;
import com.xeuse.util.CardDbAdapter;
import com.xeuse.util.PhotoCard;

public class MainActivity extends BaseActivity {

	private static final int CAMERA_REQUEST = 0;
	private static final String TEMP_PHOTONAME = "temp.jpg";
	
	private ListView listView1;
	private Context context;
	private Uri cameraFileUri;
	private CardDbAdapter mDbHelper;
	private DownloadFeedTask feedTask;
	private ClientAdapter clientAdapter;
	private TextView footer;
	private boolean isLoading = false;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		context = getApplicationContext();

		mDbHelper = new CardDbAdapter(context);
		mDbHelper.open();
		mDbHelper.clearCache();
		
		Cursor mFeedList = mDbHelper.fetchRecentCards();
			
		mDbHelper.close();

		/* Setup list view */
		listView1 = (ListView) findViewById(R.id.listView1);
		LayoutInflater inflater = (LayoutInflater) getSystemService(Context.LAYOUT_INFLATER_SERVICE);
		footer = (TextView) inflater.inflate(R.layout.list_footer, null);
		listView1.addFooterView(footer);

		/* Set up listView adapter */
		clientAdapter = new ClientAdapter(MainActivity.this, R.layout.listview_item_row, mFeedList);
		listView1.setAdapter(clientAdapter);
		listView1.setOnScrollListener(new OnScrollListener() {

			@Override
			public void onScroll(AbsListView view, int firstVisibleItem, int visibleItemCount, int totalItemCount) {
				int loadedItems = firstVisibleItem + visibleItemCount;
				if((loadedItems == totalItemCount) && !isLoading){				
					if (feedTask != null && (feedTask.getStatus() == AsyncTask.Status.FINISHED) ) {
						feedTask = new DownloadFeedTask();
						feedTask.execute(FEED_URL);
					}
				}
			}

			@Override
			public void onScrollStateChanged(AbsListView arg0, int arg1) {}

		});

		feedTask = new DownloadFeedTask();
		feedTask.execute(FEED_URL);

	}
	
	@Override
	protected int getLayoutResourceId() {
		return R.layout.activity_main;
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
	    MenuInflater inflater = getSupportMenuInflater();
	    inflater.inflate(R.menu.options_menu, menu);
	    return super.onCreateOptionsMenu(menu);
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {

	    switch (item.getItemId()) {
		    case R.id.opt_settings:
		    	
		    	/* Launch app settings */
		        Intent preferencesIntent = new Intent(this, Preferences.class);
		        startActivity(preferencesIntent);
		        return true;

		    case R.id.menu_add_photo:

				/* Launch camera/gallery upload */
		    	AlertDialog.Builder builder = new AlertDialog.Builder(MainActivity.this);
		    	builder.setTitle(R.string.submit_photo).setItems(R.array.camera_options_array, new DialogInterface.OnClickListener() {
		    		@Override
					public void onClick(DialogInterface dialog, int optionChosen) {
						if (optionChosen == 0) {							
							
							Intent intent = new Intent("android.media.action.IMAGE_CAPTURE");
							
							File fileDir = new File(Environment.getExternalStorageDirectory(), "/" + STORAGE_DIR);
							if (!fileDir.isDirectory()) {
								fileDir.mkdirs();
							}
							
							File photoImage = new File(Environment.getExternalStorageDirectory() + "/" + STORAGE_DIR, TEMP_PHOTONAME);						
							Log.d(DEBUG_TAG, "Exists in"+ photoImage.getPath());
							
							cameraFileUri = Uri.fromFile(photoImage);
							intent.putExtra(MediaStore.EXTRA_OUTPUT, cameraFileUri);
							startActivityForResult(intent, CAMERA_REQUEST);
						}
					}
				});
		    	builder.show();
		    	return true;

		    default:
		        return super.onOptionsItemSelected(item);
	    }
	}
	
	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		
		if ((requestCode == CAMERA_REQUEST) && (resultCode == Activity.RESULT_OK)) {
			// Check if the result includes a thumbnail Bitmap, if it does then load large btmp
			
			if (data == null) {
				try {
				    //TODO Do something with the full image stored in outputFileUri. Perhaps copying it to the app folder					
					Bitmap photo1 = MediaStore.Images.Media.getBitmap(this.getContentResolver(), cameraFileUri);
					Log.d(DEBUG_TAG, "saved uri 1: " + cameraFileUri.toString() + " Image size: " + photo1.getWidth());
				} catch (FileNotFoundException e) {
					e.printStackTrace();
				} catch (IOException e) {
					e.printStackTrace();
				}			
			} else {
				Bitmap photo = (Bitmap) data.getExtras().get("data");
				Log.d(DEBUG_TAG, "saved uri 2: " + cameraFileUri.toString() + " Image size: " + photo.getWidth());				
			}
		}
		
		Intent intent = new Intent(context, UploadPictureActivity.class);
		intent.putExtra("IMAGE_URI", cameraFileUri);
		startActivity(intent);
		
	}
	
	private class DownloadFeedTask extends AsyncTask<String, Object, ArrayList<PhotoCard>> {
		
		public void onPreExecute() {
			mDbHelper.open();
			isLoading = true;
		}
		
		@Override
		protected ArrayList<PhotoCard> doInBackground (String... params){
			return doGetJson(params[0]);
		}
		
		public ArrayList<PhotoCard> doGetJson(String url) {
		     
			ArrayList<PhotoCard> feedList = new ArrayList<PhotoCard>();
			 
			try { 
				
				DefaultHttpClient defaultClient = new DefaultHttpClient();
			    HttpGet httpGetRequest = new HttpGet(url);
			    
			 	HttpResponse httpResponse = defaultClient.execute(httpGetRequest);
			 	
			 	BufferedReader reader = new BufferedReader(new InputStreamReader(httpResponse.getEntity().getContent(), "UTF-8"));
			 	String jsonData = reader.readLine();
			 	 
			 	JSONObject obj = new JSONObject(jsonData);		 	
			    //the array title that you parse
		 		JSONArray userCard = obj.getJSONArray("result");
		 		
	 			for (int i = 0; i < userCard.length(); i++) {
		 			
		 			JSONObject jsonRow = userCard.getJSONObject(i);
		 			mDbHelper.insertCard(jsonRow.getInt("id"), jsonRow.getString("name"), jsonRow.getString("description"));

		 		}

			} catch (JSONException e) {
				Log.d(DEBUG_TAG, "Error1");
				e.printStackTrace();
			} catch (ClientProtocolException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}
	 		
			return feedList;

		}
		
		protected void onPostExecute(ArrayList<PhotoCard> feedList){

			isLoading = false;

			Cursor mFeedList = mDbHelper.fetchRecentCards();
			clientAdapter.changeCursor(mFeedList);
            mDbHelper.close();

       }
		
	}

}
		     


		 	

		   

	


