package com.xeuse.stuffmypetdestroyed;

import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.graphics.Color;
import android.os.Bundle;
import android.support.v4.view.PagerAdapter;
import android.support.v4.view.ViewPager;
import android.util.Log;
import android.util.TypedValue;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.xeuse.util.CardDbAdapter;
import com.xeuse.util.ImageDownloader;

public class ViewCardActivity extends BaseActivity {

	private CardDbAdapter db;
	private Context context;
	private Cursor cardCursor;
	private PhotoPagerAdapter photoAdapter;
	private ViewPager photoViewPager;
	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		context = getApplicationContext();

		Bundle extras = getIntent().getExtras();	
		if (extras != null) {
		
			int item = extras.getInt("CARD_ITEM");
			Log.d(DEBUG_TAG, "Clicked item: " + item);

			db = new CardDbAdapter(context);
			db.open();
			
			try {
				cardCursor = db.fetchCard(item);
			} catch (SQLException e) {
				Log.d(DEBUG_TAG, "Error with SQL: " + e.toString());
			}

			photoAdapter = new PhotoPagerAdapter();
			
			photoViewPager = (ViewPager) findViewById(R.id.photo_pager);
			
			int pagerMargin = convertDip2Pixels(context, 10);

			photoViewPager.setPageMargin(pagerMargin);
			photoViewPager.setAdapter(photoAdapter);

			populateCard();
		
		}
	}
	
	public static int convertDip2Pixels(Context context, int dip) {
		return (int) TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, dip, context.getResources().getDisplayMetrics());
	}
	
	private void populateCard() {
		
		//Card Submission Name
		TextView cardName = (TextView) findViewById(R.id.cardTitle);
		cardName.setText(cardCursor.getString(2));
		
		//Card Submission Description
		TextView cardDesc = (TextView) findViewById(R.id.cardDescription);
		cardDesc.setText(cardCursor.getString(3));
		
		//Card Submission Image
		//ImageView cardImage = (ImageView) findViewById(R.id.uploadImageView);
		//String url = "http://symfony.phonecompare.co.uk/" + cardCursor.getInt(1) + "_l.jpg";

		//ImageDownloader imgDownloader = new ImageDownloader(); 
		//imgDownloader.download(url, cardImage);

	}
	
	@Override
	protected int getLayoutResourceId() {
		return R.layout.activity_view_card;
	}
	
	public class PhotoPagerAdapter extends PagerAdapter {

		private LayoutInflater inflater;
		
		public PhotoPagerAdapter() {
			inflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
		}
		
		@Override
		public int getCount() {
			return 3;
		}
		
        @Override
        public Object instantiateItem(ViewGroup collection, int position) {
        	
        	View galleryLayout = inflater.inflate(R.layout.view_card_pager_icon, null);
        	ImageView galleryImage = (ImageView) galleryLayout.findViewById(R.id.uploadImageView);
        	
    		String url = "http://symfony.phonecompare.co.uk/" + cardCursor.getInt(1) + "_l.jpg";

    		ImageDownloader imgDownloader = new ImageDownloader(); 
    		imgDownloader.download(url, galleryImage);
        	
            collection.addView(galleryLayout,0);
                
            return galleryLayout;
        }

        @Override
        public boolean isViewFromObject(View view, Object object) {
        	return (view==object);
        }
		
        @Override
        public void destroyItem(ViewGroup collection, int position, Object view) {
        	collection.removeView((LinearLayout) view);
        }


		
	}


}