package com.xeuse.util;

import android.content.Context;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteDatabase.CursorFactory;
import android.database.sqlite.SQLiteException;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public abstract class AbstractDbAdapter {

	protected static final String CARDS_TABLE_NAME = "cards";
	protected static final String TAG = "AbstractDbAdapter";

	protected DatabaseHelper mDbHelper;
	protected SQLiteDatabase mDb;
	
	private static final String DATABASE_NAME = "library.db";
	private static final int DATABASE_VERSION = 1;

	private static final String CARDS_DB_CREATE = "CREATE TABLE "
			+ CARDS_TABLE_NAME + " ("
			+ "_id INTEGER PRIMARY KEY AUTOINCREMENT,"
			+ "import_id integer not null,"
			+ "name TEXT not null,"
			+ "description TEXT not null,"
			+ "date_added TIMESTAMP DEFAULT CURRENT_TIMESTAMP,"
			+ "last_viewed TIMESTAMP);";

	private final Context mCtx;
	
	private static class DatabaseHelper extends SQLiteOpenHelper {

		public DatabaseHelper(Context context, String name, CursorFactory factory, int version) {
			super(context, name, factory, version);
		}

		@Override
		public void onCreate(SQLiteDatabase db) {
			/* Create Stack Database Table */
			try {
				Log.d(TAG, "Creating database");
				db.execSQL(CARDS_DB_CREATE);
			} catch (SQLiteException e) {
				Log.d(TAG, "Error creating database: " + e.getStackTrace());
			}
		}

		@Override
		public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
			Log.w(TAG, "Upgrading database from version " + oldVersion + " to "
					+ newVersion + ", which will destroy all old data");
			db.execSQL("DROP TABLE IF EXISTS " + CARDS_DB_CREATE);
		}

	}

	public AbstractDbAdapter(Context ctx) {
		this.mCtx = ctx;
	}

	public AbstractDbAdapter open() throws SQLException {
		mDbHelper = new DatabaseHelper(mCtx, DATABASE_NAME, null, DATABASE_VERSION);
		mDb = mDbHelper.getWritableDatabase();
		return this;
	}

	public void close() {
		mDbHelper.close();
	}
	

}